@@ -4,17 +4,19 @@
 #
 use strict;
 use warnings;
-use Test::More tests => 15;
+use Test::More tests => 28;
 use ExtUtils::MakeMaker qw(prompt);
 
+use Data::Dumper;
+
 my %film_info = (
-	Aa => { code    		=> '332452', },
-	Ba => { title   		=> 'Troy', },
-	Ca => { year    		=> '2004',},
-	Da => { genres			=> [qw(Action Drama War Adventure Romance)], },
-	Fa => { country 		=> [qw(USA)], },
-	Ga => { language		=> [qw(English)], },
-	Ia => { certifications	=> { 	Argentina => 13 , 
+	code    		=> '0332452',
+	title   		=> 'Troy',
+	year    		=> '2004',
+	genres			=> [qw(Action Drama War Adventure Romance)],
+	country 		=> [qw(USA)],
+	language		=> [qw(English)],
+	certifications	=> { 	Argentina => 13 , 
 									Australia=>'MA', 
 									Australia=>'M',
 									Brazil=>14, 
@@ -35,10 +37,10 @@ my %film_info = (
 									Singapore=>'PG',
 									Switzerland=>12,
 									UK=>15,
-									USA=>'R' }, },
-	Db => { plot			=> qq{An adaptation of Homer's great epic, the film follows the assault on Troy by the united Greek forces and chronicles the fates of the men involved.} },								
-	Cb => { cover			=> qq{http://ia.imdb.com/media/imdb/01/I/54/16/28m.jpg}, },
-	Dd => { casts			=> [{ 	id => '0002103', name => 'Julian Glover'},	
+									USA=>'R' },
+	plot			=> qq{An adaptation of Homer's great epic, the film follows the assault on Troy by the united Greek forces and chronicles the fates of the men involved.},								
+	cover			=> qq{http://ia.imdb.com/media/imdb/01/I/54/16/28m.jpg},
+	casts			=> [{ 	id => '0002103', name => 'Julian Glover'},	
 								{	id => '0004051', name => 'Brian Cox'},		
 								{	id => '0428923', name => 'Nathan Jones'},	
 								{	id => '0549539', name => 'Adoni Maropis'},									
@@ -52,11 +54,11 @@ my %film_info = (
 								{	id => '1595495', name => 'Siri Svegler'},	
 								{	id => '1595480', name => 'Lucie Barat'},		
 								{	id => '0094297', name => 'Ken Bones'},		
-								{	id => '0146439', name => 'Manuel Cauchi'} ] },
+								{	id => '0146439', name => 'Manuel Cauchi'} ],
 
-	Cd => { directors		=> [{id => '0000583', name => 'Wolfgang Petersen'}] },
-	Ce => { writers			=> [{id => '0392955', name => 'Homer'}, 
-								{id => '1125275', name => 'David Benioff'}] },
+	directors		=> [{id => '0000583', name => 'Wolfgang Petersen'}],
+	writers			=> [{id => '0392955', name => 'Homer'}, 
+								{id => '1125275', name => 'David Benioff'}],
 
 	);							
 
@@ -65,25 +67,38 @@ require_ok('IMDB::Film');
 my $online_test = prompt("\nDo you want to connect to IMDB?", "Y");
 
 SKIP: {
-	skip "online test!", 14 if $online_test =~ /^(n|q)/i;
+	skip "online test!", 27 if $online_test =~ /^(n|q)/i;
 
-	print "\nTesting film '$film_info{Ba}{title}' [$film_info{Aa}{code}] ...\n";
+	print "\nTesting film '$film_info{title}' [$film_info{code}] ...\n";
 
 	my $proxy = $ENV{http_proxy} ? $ENV{http_proxy} : 'no';
 	$proxy = prompt("\nUse proxy?", "$proxy");
 	print "\n";
 
-	my %pars = (crit => $film_info{Aa}{code});
+	my %pars = (crit => $film_info{code});
 	$pars{proxy} = $proxy if defined $proxy && $proxy !~ /^no/i;
 	$pars{cache} = 0;
 	$pars{debug} = 1;
 	my $film = new IMDB::Film(%pars);
 
 	isa_ok($film, 'IMDB::Film');
+	
+	compare_props($film);
+	
+	print "Test search film by title [$film_info{title}] ...\n";
 
-	for my $item ( sort keys %film_info ) {
-		my ($key, $val) = each %{ $film_info{$item} };
-		
+	$pars{crit} = $film_info{title};
+
+	$film = new IMDB::Film(%pars);
+	
+	compare_props($film);
+};
+
+sub compare_props {
+	my $film = shift;
+
+	for my $key ( sort keys %film_info ) {
+		my $val = $film_info{$key};	
 		if(ref($val)) {
 			is_deeply($film->$key, $val, $key);
 		} else {
@@ -92,4 +107,4 @@ SKIP: {
 	}
 
 	like($film->rating(), qr/\d+\.\d+/, 'rating');
-};
+}
